<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro" sourcelanguage="en">
  <context>
    <name>CmdDrawingAnnotation</name>
    <message>
      <location filename="../../Command.cpp" line="481"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="482"/>
      <source>&amp;Annotation</source>
      <translation>&amp;Adnotație</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="483"/>
      <location filename="../../Command.cpp" line="485"/>
      <source>Inserts an Annotation view in the active drawing</source>
      <translation>Inserează o vizualizare de adnotație în desenul activ</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingClip</name>
    <message>
      <location filename="../../Command.cpp" line="529"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="530"/>
      <source>&amp;Clip</source>
      <translation>&amp;Clip</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="531"/>
      <location filename="../../Command.cpp" line="533"/>
      <source>Inserts a clip group in the active drawing</source>
      <translation>Inserează un grup de clipuri în desenul activ</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingDraftView</name>
    <message>
      <location filename="../../Command.cpp" line="728"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="729"/>
      <source>&amp;Draft View</source>
      <translation>Vue &amp;Draft</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="730"/>
      <location filename="../../Command.cpp" line="732"/>
      <source>Inserts a Draft view of the selected object(s) in the active drawing</source>
      <translation>Insère une vue brouillon des objets sélectionnés dans le dessin actif</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingExportPage</name>
    <message>
      <location filename="../../Command.cpp" line="635"/>
      <source>File</source>
      <translation>Fişier</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="636"/>
      <source>&amp;Export page...</source>
      <translation>&amp;Exportă pagina...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="637"/>
      <location filename="../../Command.cpp" line="639"/>
      <source>Export a page to an SVG file</source>
      <translation>Exportă pagina într-un fişier SVG</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewA3Landscape</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <location filename="../../Command.cpp" line="277"/>
      <source>Insert new A3 landscape drawing</source>
      <translation>Inserare A3 nou format peisaj</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewPage</name>
    <message>
      <location filename="../../Command.cpp" line="97"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="98"/>
      <location filename="../../Command.cpp" line="99"/>
      <source>Insert new drawing</source>
      <translation>Inserează un desen nou</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingNewView</name>
    <message>
      <location filename="../../Command.cpp" line="314"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="315"/>
      <source>Insert view in drawing</source>
      <translation>Inseraţi vizualizare în desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="316"/>
      <source>Insert a new View of a Part in the active drawing</source>
      <translation>Insereaza o nouă vizualizare a unei piese în desenul activ</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpen</name>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="61"/>
      <source>Open SVG...</source>
      <translation>Deschide SVG ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="62"/>
      <source>Open a scalable vector graphic</source>
      <translation>Deschide o imagine grafică vectorială scalabilă</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOpenBrowserView</name>
    <message>
      <location filename="../../Command.cpp" line="443"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="444"/>
      <source>Open &amp;browser view</source>
      <translation>Deschideți &amp;browser-ul</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="445"/>
      <location filename="../../Command.cpp" line="447"/>
      <source>Opens the selected page in a browser view</source>
      <translation>Deschide pagina selectată într-un browser</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingOrthoViews</name>
    <message>
      <location filename="../../Command.cpp" line="393"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="394"/>
      <source>Insert orthographic views</source>
      <translation>Inserați vederi ortogonale</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="395"/>
      <source>Insert an orthographic projection of a part in the active drawing</source>
      <translation>Inseraţi o proiecţie ortogonală a unei componente în desenul activ</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingProjectShape</name>
    <message>
      <location filename="../../Command.cpp" line="692"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="693"/>
      <source>Project shape...</source>
      <translation>Proiectează forma...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="694"/>
      <location filename="../../Command.cpp" line="695"/>
      <source>Project shape onto a user-defined plane</source>
      <translation>Proiectează forma pe un plan definit de către utilizator</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSpreadsheetView</name>
    <message>
      <location filename="../../Command.cpp" line="759"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="760"/>
      <source>&amp;Spreadsheet View</source>
      <translation>Vedere &amp; Foaie de calcul</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="761"/>
      <location filename="../../Command.cpp" line="763"/>
      <source>Inserts a view of a selected spreadsheet in the active drawing</source>
      <translation>Introduceți o vedere cu o foaie de calcul selectată într-un desen activ</translation>
    </message>
  </context>
  <context>
    <name>CmdDrawingSymbol</name>
    <message>
      <location filename="../../Command.cpp" line="574"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="575"/>
      <source>&amp;Symbol</source>
      <translation>&amp;Simbol</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="576"/>
      <location filename="../../Command.cpp" line="578"/>
      <source>Inserts a symbol from a svg file in the active drawing</source>
      <translation>Inserează un simbol dintr-un fișier svg în desenul activ</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::DrawingView</name>
    <message>
      <location filename="../../DrawingView.cpp" line="219"/>
      <source>&amp;Background</source>
      <translation>&amp;Fundal </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="225"/>
      <source>&amp;Outline</source>
      <translation>&amp;Contur</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="231"/>
      <source>&amp;Native</source>
      <translation>&amp;Nativ </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="235"/>
      <source>&amp;OpenGL</source>
      <translation>&amp;OpenGL </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="238"/>
      <source>&amp;Image</source>
      <translation>&amp;Imagine </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="242"/>
      <source>&amp;High Quality Antialiasing</source>
      <translation>&amp;Antialiasing de înaltă calitate</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="284"/>
      <source>Open SVG File</source>
      <translation>Deschide fişier SVG </translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="285"/>
      <source>Could not open file '%1'.</source>
      <translation>Fişierul '%1' nu a putut fi deschis.</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="408"/>
      <source>&amp;Renderer</source>
      <translation>&amp;Renderizator</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="513"/>
      <source>Export PDF</source>
      <translation>Export format PDF</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="514"/>
      <source>PDF file</source>
      <translation>Fişier PDF</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="530"/>
      <source>Page sizes</source>
      <translation>Dimensiuni de pagină</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="532"/>
      <location filename="../../DrawingView.cpp" line="545"/>
      <source>A0</source>
      <translation>A0</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="534"/>
      <location filename="../../DrawingView.cpp" line="547"/>
      <source>A1</source>
      <translation>A1</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="536"/>
      <location filename="../../DrawingView.cpp" line="549"/>
      <source>A2</source>
      <translation>A2</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="538"/>
      <location filename="../../DrawingView.cpp" line="551"/>
      <source>A3</source>
      <translation>A3</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="540"/>
      <location filename="../../DrawingView.cpp" line="553"/>
      <source>A4</source>
      <translation>A4</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="542"/>
      <location filename="../../DrawingView.cpp" line="555"/>
      <source>A5</source>
      <translation>A5</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="666"/>
      <source>Different orientation</source>
      <translation>Orientare diferită</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="667"/>
      <source>The printer uses a different orientation than the drawing.
Do you want to continue?</source>
      <translation>Imprimanta utilizează o orientare diferită a hârtiei decât desenul. Doriţi să continuaţi?</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="674"/>
      <location filename="../../DrawingView.cpp" line="682"/>
      <source>Different paper size</source>
      <translation>Hârtie de dimensiune diferită</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="675"/>
      <location filename="../../DrawingView.cpp" line="683"/>
      <source>The printer uses a different paper size than the drawing.
Do you want to continue?</source>
      <translation>Imprimanta utilizează o altă dimensiune de hârtie decât desenul. Doriţi să continuaţi?</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="694"/>
      <source>Opening file failed</source>
      <translation>Deschiderea fișierului a eșuat</translation>
    </message>
    <message>
      <location filename="../../DrawingView.cpp" line="695"/>
      <source>Can't open file '%1' for writing.</source>
      <translation>Fișierul r '%1' nu acceptă scrierea.</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskOrthoViews</name>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="26"/>
      <source>Orthographic Projection</source>
      <translation>Proiecţie Ortogonală</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="46"/>
      <location filename="../../TaskOrthoViews.ui" line="71"/>
      <location filename="../../TaskOrthoViews.ui" line="96"/>
      <location filename="../../TaskOrthoViews.ui" line="121"/>
      <location filename="../../TaskOrthoViews.ui" line="146"/>
      <location filename="../../TaskOrthoViews.ui" line="177"/>
      <location filename="../../TaskOrthoViews.ui" line="202"/>
      <location filename="../../TaskOrthoViews.ui" line="227"/>
      <location filename="../../TaskOrthoViews.ui" line="252"/>
      <location filename="../../TaskOrthoViews.ui" line="277"/>
      <location filename="../../TaskOrthoViews.ui" line="302"/>
      <location filename="../../TaskOrthoViews.ui" line="362"/>
      <source>Right click for axonometric settings</source>
      <translation>Click dreapta pentru configurări axonometrice</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="324"/>
      <source>Primary view</source>
      <translation>Vederea principală</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="340"/>
      <source>Secondary Views</source>
      <translation>Vederi secundare</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="412"/>
      <source>General</source>
      <translation>General</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="421"/>
      <source>Auto scale / position</source>
      <translation>Auto scalare / poziţionare</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="436"/>
      <source>Scale</source>
      <translation>Scalare</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="468"/>
      <source>Top left x / y</source>
      <translation>Sus stânga x / y</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="516"/>
      <source>Spacing dx / dy</source>
      <translation>Distanțează dx / dy</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="561"/>
      <source>Show hidden lines</source>
      <translation>Afișează liniile ascunse</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="568"/>
      <source>Show smooth lines</source>
      <translation>Se afişează liniile subțiri</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="579"/>
      <source>Axonometric</source>
      <translation>Axonometric</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="587"/>
      <source>Axis out and right</source>
      <translation>Sensul axei spre dreapta</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="594"/>
      <source>Vertical tilt</source>
      <translation>Înclinare verticală</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="605"/>
      <location filename="../../TaskOrthoViews.ui" line="805"/>
      <source>X +ve</source>
      <translation>X +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="610"/>
      <location filename="../../TaskOrthoViews.ui" line="685"/>
      <location filename="../../TaskOrthoViews.ui" line="810"/>
      <source>Y +ve</source>
      <translation>Y +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="615"/>
      <location filename="../../TaskOrthoViews.ui" line="690"/>
      <location filename="../../TaskOrthoViews.ui" line="815"/>
      <source>Z +ve</source>
      <translation>Z +ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="620"/>
      <location filename="../../TaskOrthoViews.ui" line="820"/>
      <source>X -ve</source>
      <translation>X -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="625"/>
      <location filename="../../TaskOrthoViews.ui" line="695"/>
      <location filename="../../TaskOrthoViews.ui" line="825"/>
      <source>Y -ve</source>
      <translation>Y -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="630"/>
      <location filename="../../TaskOrthoViews.ui" line="700"/>
      <location filename="../../TaskOrthoViews.ui" line="830"/>
      <source>Z -ve</source>
      <translation>Z -ve</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="642"/>
      <source>Isometric</source>
      <translation>Izometrică</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="647"/>
      <source>Dimetric</source>
      <translation>Dimetric</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="652"/>
      <source>Trimetric</source>
      <translation>Trimetric</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="660"/>
      <source> Scale</source>
      <translation> Scală</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="667"/>
      <source>View projection</source>
      <translation>Vizualizează proiecția</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="674"/>
      <source> Axis aligned up</source>
      <translation> Axa aliniată sus</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="715"/>
      <location filename="../../TaskOrthoViews.ui" line="738"/>
      <source>Flip</source>
      <translation>Întoarce</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="728"/>
      <source> Trimetric</source>
      <translation> Trimetric</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="756"/>
      <source>Projection</source>
      <translation>Proiecţie</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="767"/>
      <source>Third Angle</source>
      <translation>Convenția/proiecția americană</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="772"/>
      <source>First Angle</source>
      <translation>Convenția/proiecția europeană</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="791"/>
      <source>View from:</source>
      <translation>Vizualizare de la:</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.ui" line="838"/>
      <source>Axis aligned right:</source>
      <translation>Axa aliniată la dreapta:</translation>
    </message>
  </context>
  <context>
    <name>DrawingGui::TaskProjection</name>
    <message>
      <location filename="../../TaskDialog.cpp" line="51"/>
      <source>Visible sharp edges</source>
      <translation>Muchiile ascuțite vizibile</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="52"/>
      <source>Visible smooth edges</source>
      <translation>Muchiile netede vizibile</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="53"/>
      <source>Visible sewn edges</source>
      <translation>Muchiile îmbinate vizibile</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="54"/>
      <source>Visible outline edges</source>
      <translation>Muchiile de contur vizibile</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="55"/>
      <source>Visible isoparameters</source>
      <translation>Isoparametrii vizibili</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="56"/>
      <source>Hidden sharp edges</source>
      <translation>Muchiile ascuțite ascunse</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="57"/>
      <source>Hidden smooth edges</source>
      <translation>Muchiile netede ascunse</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="58"/>
      <source>Hidden sewn edges</source>
      <translation>Muchiile îmbinate ascunse</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="59"/>
      <source>Hidden outline edges</source>
      <translation>Muchiile de contur ascunse</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="60"/>
      <source>Hidden isoparameters</source>
      <translation>Isoparametrii ascunși</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="77"/>
      <source>Project shapes</source>
      <translation>Proiectează formele</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="91"/>
      <source>No active document</source>
      <translation>Nici un document activ</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="92"/>
      <source>There is currently no active document to complete the operation</source>
      <translation>Nu este nici un document activ pentru a termina operațiunea</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="97"/>
      <source>No active view</source>
      <translation>Nici o vedere activă</translation>
    </message>
    <message>
      <location filename="../../TaskDialog.cpp" line="98"/>
      <source>There is currently no active view to complete the operation</source>
      <translation>Acum nu este nici o vedere activă pentru a termina operațiunea</translation>
    </message>
  </context>
  <context>
    <name>Drawing_NewPage</name>
    <message>
      <location filename="../../Command.cpp" line="223"/>
      <source>Landscape</source>
      <translation>Peisaj</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="225"/>
      <source>Portrait</source>
      <translation>Orientare tip portret</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="229"/>
      <source>%1%2 %3</source>
      <translation>%1%2 %3</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="234"/>
      <source>Insert new %1%2 %3 drawing</source>
      <translation>Inserează un nou %1%2%3 desen</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="241"/>
      <source>%1%2 %3 (%4)</source>
      <translation>%1%2 %3 (%4)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="247"/>
      <source>Insert new %1%2 %3 (%4) drawing</source>
      <translation>Inserare desen nou %1%2 %3 (%4)</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="72"/>
      <location filename="../../Command.cpp" line="595"/>
      <source>Choose an SVG file to open</source>
      <translation>Alegeţi un fişier SVG pentru deschidere</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="73"/>
      <location filename="../../Command.cpp" line="596"/>
      <location filename="../../Command.cpp" line="654"/>
      <source>Scalable Vector Graphic</source>
      <translation>Vector Grafic Scalabil (Svg)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="327"/>
      <location filename="../../Command.cpp" line="406"/>
      <location filename="../../Command.cpp" line="456"/>
      <location filename="../../Command.cpp" line="648"/>
      <location filename="../../Command.cpp" line="772"/>
      <source>Wrong selection</source>
      <translation>Selecție greșită</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="328"/>
      <source>Select a Part object.</source>
      <translation>Selecteaza un obiect tip piesă</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="336"/>
      <location filename="../../Command.cpp" line="415"/>
      <location filename="../../Command.cpp" line="496"/>
      <location filename="../../Command.cpp" line="544"/>
      <location filename="../../Command.cpp" line="589"/>
      <location filename="../../Command.cpp" line="778"/>
      <source>No page found</source>
      <translation>Pagină negăsită</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="337"/>
      <location filename="../../Command.cpp" line="416"/>
      <location filename="../../Command.cpp" line="497"/>
      <location filename="../../Command.cpp" line="545"/>
      <location filename="../../Command.cpp" line="590"/>
      <location filename="../../Command.cpp" line="779"/>
      <source>Create a page first.</source>
      <translation>Creați /selectați o pagină mai întâi.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="407"/>
      <source>Select exactly one Part object.</source>
      <translation>Selectați doar un singur obiect tip Piesă.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="457"/>
      <location filename="../../Command.cpp" line="649"/>
      <source>Select one Page object.</source>
      <translation>Selectează un obiect pagină</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="655"/>
      <source>All Files</source>
      <translation>Toate fișierele</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="657"/>
      <source>Export page</source>
      <translation>Exportă pagina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="773"/>
      <source>Select exactly one Spreadsheet object.</source>
      <translation>Selectați doar un singur obiect tip foaie de calcul Spreadsheet.</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="54"/>
      <location filename="../../TaskOrthoViews.cpp" line="982"/>
      <source>Make axonometric...</source>
      <translation>Fă-l axonometric...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="55"/>
      <location filename="../../TaskOrthoViews.cpp" line="983"/>
      <source>Edit axonometric settings...</source>
      <translation>Editare configurări axonometrice...</translation>
    </message>
    <message>
      <location filename="../../TaskOrthoViews.cpp" line="56"/>
      <location filename="../../TaskOrthoViews.cpp" line="984"/>
      <source>Make orthographic</source>
      <translation>Fă-l ortogonal</translation>
    </message>
    <message>
      <location filename="../../ViewProviderPage.cpp" line="152"/>
      <source>Show drawing</source>
      <translation>Arată desenul</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Drawing</source>
      <translation>Desen</translation>
    </message>
  </context>
</TS>
